@@ -13,9 +13,6 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
-from airflow.providers.postgres.hooks.postgres import PostgresHook
-from psycopg2 import sql
-
 from astro.sql.table import Table
 
 
